diff --git a/agc_2-X/trunk/www/vicidial/callbacks_bulk_move.php b/agc_2-X/trunk/www/vicidial/callbacks_bulk_move.php
index 82c78457..228a0206 100644
--- a/agc_2-X/trunk/www/vicidial/callbacks_bulk_move.php
+++ b/agc_2-X/trunk/www/vicidial/callbacks_bulk_move.php
@@ -330,12 +330,12 @@ $NWB = "
";
### PRELOAD ###
+$preload_campaigns=array();
+$preload_lists=array();
+$preload_user_groups=array();
+$preload_users=array();
if ($campaign_id)
{
- $preload_campaigns=array();
- $preload_lists=array();
- $preload_user_groups=array();
- $preload_users=array();
# Trying a three-level UNION statement to see if that's faster
$stmt="SELECT distinct campaign_id, 'CAMPAIGN' as dtype FROM vicidial_callbacks where campaign_id='$campaign_id' UNION SELECT distinct user_group, 'USER_GROUP' as dtype FROM vicidial_callbacks where campaign_id='$campaign_id' UNION SELECT distinct list_id, 'LIST_ID' as dtype from vicidial_callbacks where campaign_id='$campaign_id' UNION SELECT distinct user, 'USER' as dtype from vicidial_callbacks where campaign_id='$campaign_id' order by dtype asc;";
$rslt=mysql_to_mysqli($stmt, $link);
diff --git a/agc_2-X/trunk/www/agc/vicidial.php b/agc_2-X/trunk/www/agc/vicidial.php
index 9b4a1906..b5aae049 100644
--- a/agc_2-X/trunk/www/agc/vicidial.php
+++ b/agc_2-X/trunk/www/agc/vicidial.php
@@ -478,11 +478,11 @@
# 150204-1911 - Changed Manual hotkey auto-manual-dial to a variable delay depending on dispo processing time
# 150210-1225 - Added LOCK options for manual_dial_search_checkbox, fixed missing QXZ tags(issue #827)
# 150212-0034 - Added case-sensitive user validation(issue #682)
# 150218-1111 - Fixes for QXZ enclosed in single-quotes
#
$version = '2.10-450c';
-$build = '150218-1111';
+$build = '150218-1356';
$mel=1; # Mysql Error Log enabled = 1
$mysql_log_count=85;
$one_mysql_log=0;
@@ -12195,11 +12195,11 @@ function set_length(SLnumber,SLlength_goal,SLdirection)
refresh_interval = 7300000;
var logout_content='';
if (tempreason=='SHIFT')
- {logout_content='
';}
+ {logout_content="
";}
if (tempreason=='API')
- {logout_content='
';}
+ {logout_content="
";}
if (tempreason=='TIMEOUT')
- {logout_content='
';}
+ {logout_content="
";}
document.getElementById("LogouTBoxLink").innerHTML = logout_content + "\n";
@@ -14658,7 +14658,7 @@ function phone_number_format(formatphone) {
if (customer_3way_hangup_action=='DISPO')
{
- customer_3way_hangup_dispo_message='';
+ customer_3way_hangup_dispo_message="";
bothcall_send_hangup();
}
}
@@ -15122,13 +15122,13 @@ function phone_number_format(formatphone) {
document.getElementById("ViewCommentsShowHide").innerHTML = " - ";
}
//view_comments_active = 1;
- document.getElementById("viewcommentsdisplay").innerHTML = "";
+ document.getElementById("viewcommentsdisplay").innerHTML = "\" />";
if (comments_all_tabs == 'ENABLED')
- {document.getElementById("otherviewcommentsdisplay").innerHTML = "";}
+ {document.getElementById("otherviewcommentsdisplay").innerHTML = "\" />";}
if (VCspanname == 'dispo')
- {document.getElementById("dispoviewcommentsdisplay").innerHTML = "";}
+ {document.getElementById("dispoviewcommentsdisplay").innerHTML = "\" />";}
if (VCspanname == 'cb')
- {document.getElementById("cbviewcommentsdisplay").innerHTML = "";}
+ {document.getElementById("cbviewcommentsdisplay").innerHTML = "\" />";}
}
else
{
@@ -478,11 +478,11 @@
# 150210-1225 - Added LOCK options for manual_dial_search_checkbox, fixed missing QXZ tags(issue #827)
# 150212-0034 - Added case-sensitive user validation(issue #682)
-# 150218-1111 - Fixes for QXZ enclosed in single-quotes
+# 150218-1356 - Fixes for QXZ enclosed in single-quotes
#
$version = '2.10-450c';